@@ -1,6 +1,7 @@
 import logging, pprint, cStringIO
 from flask import Flask, jsonify, render_template, request, abort, make_response
-import version, rparse, utils
+import version, language, utils
+from netlib import http_uastrings
 
 logging.basicConfig(level="DEBUG")
 app = Flask(__name__)
@@ -13,17 +14,17 @@ def api():
         )
 
 
-    @app.route('/api/log')
-    def api_log():
-        return jsonify(
-            log = app.config["pathod"].get_log()
-        )
+@app.route('/api/log')
+def api_log():
+    return jsonify(
+        log = app.config["pathod"].get_log()
+    )
 
 
-    @app.route('/api/clear_log')
-    def api_clear_log():
-        app.config["pathod"].clear_log()
-        return "OK"
+@app.route('/api/clear_log')
+def api_clear_log():
+    app.config["pathod"].clear_log()
+    return "OK"
 
 
 def render(s, cacheable, **kwargs):
@@ -61,7 +62,7 @@ def docs_pathod():
 
 @app.route('/docs/language')
 def docs_language():
-    return render("docs_lang.html", True, section="docs")
+    return render("docs_lang.html", True, section="docs", uastrings=http_uastrings.UASTRINGS)
 
 
 @app.route('/docs/pathoc')
@@ -69,6 +70,11 @@ def docs_pathoc():
     return render("docs_pathoc.html", True, section="docs")
 
 
+@app.route('/docs/libpathod')
+def docs_libpathod():
+    return render("docs_libpathod.html", True, section="docs")
+
+
 @app.route('/docs/test')
 def docs_test():
     return render("docs_test.html", True, section="docs")
@@ -103,7 +109,6 @@ def _preview(is_request):
         section = "main",
         syntaxerror = None,
         error = None,
-        pauses = None
     )
     if not spec.strip():
         args["error"] = "Can't parse an empty spec."
@@ -111,24 +116,25 @@ def _preview(is_request):
 
     try:
         if is_request:
-            r = rparse.parse_request(app.config["pathod"].request_settings, spec)
+            r = language.parse_request(app.config["pathod"].request_settings, spec)
         else:
-            r = rparse.parse_response(app.config["pathod"].request_settings, spec)
-    except rparse.ParseException, v:
+            r = language.parse_response(app.config["pathod"].request_settings, spec)
+    except language.ParseException, v:
         args["syntaxerror"] = str(v)
         args["marked"] = v.marked()
         return render(template, False, **args)
-    except rparse.FileAccessDenied:
-        args["error"] = "File access is disabled."
-        return render(template, False, **args)
 
     s = cStringIO.StringIO()
-    args["pauses"] = r.preview_safe()
+    safe = r.preview_safe()
 
+    c = app.config["pathod"].check_policy(safe, app.config["pathod"].request_settings)
+    if c:
+        args["error"] = c
+        return render(template, False, **args)
     if is_request:
-        r.serve(s, check=app.config["pathod"].check_policy, host="example.com")
+        language.serve(safe, s, app.config["pathod"].request_settings, "example.com")
     else:
-        r.serve(s, check=app.config["pathod"].check_policy)
+        language.serve(safe, s, app.config["pathod"].request_settings, None)
 
     args["output"] = utils.escape_unprintables(s.getvalue())
     return render(template, False, **args)
