@@ -26,9 +26,10 @@ def get_header(val, headers):
     """
         Header keys may be Values, so we have to "generate" them as we try the match.
     """
-    for k, v in headers:
-        if len(k) == len(val) and k[:].lower() == val:
-            return v
+    for h in headers:
+        k = h.key.get_generator({})
+        if len(k) == len(val) and k[:].lower() == val.lower():
+            return h
     return None
 
 
