@@ -11,10 +11,15 @@ class TestApp(tutils.DaemonTests):
         r = self.getpath("/about")
         assert r.ok
 
+    def test_download(self):
+        r = self.getpath("/download")
+        assert r.ok
+
     def test_docs(self):
         assert self.getpath("/docs/pathod").status_code == 200
         assert self.getpath("/docs/pathoc").status_code == 200
         assert self.getpath("/docs/language").status_code == 200
+        assert self.getpath("/docs/libpathod").status_code == 200
         assert self.getpath("/docs/test").status_code == 200
 
     def test_log(self):
@@ -42,9 +47,13 @@ class TestApp(tutils.DaemonTests):
         assert r.status_code == 200
         assert 'Response' in r.content
 
-        r = self.getpath("/response_preview", params=dict(spec="200:b<foo"))
+        r = self.getpath("/response_preview", params=dict(spec="200:b<nonexistent"))
         assert r.status_code == 200
-        assert 'File access is disabled' in r.content
+        assert 'File access denied' in r.content
+
+        r = self.getpath("/response_preview", params=dict(spec="200:b<file"))
+        assert r.status_code == 200
+        assert 'testfile' in r.content
 
     def test_request_preview(self):
         r = self.getpath("/request_preview", params=dict(spec="get:/"))
